[![Build Status](https://travis-ci.org/esnet/arborq.svg?branch=master)](https://travis-ci.org/esnet/arborq) [![Coverage Status](https://coveralls.io/repos/github/esnet/arborq/badge.svg?branch=master)](https://coveralls.io/github/esnet/arborq?branch=master)

# arborq -- a simple Python library to query Arbor Peakflow devices
